@@ -1,7 +1,7 @@
 use proc_macro2::{Span, TokenStream};
 
 use heck::SnakeCase;
-use syn::{self, Data, Ident, Variant, Fields};
+use syn::{self, Data, Fields, Ident, Variant};
 
 use super::Context;
 
@@ -15,7 +15,9 @@ pub fn transcoder_decorator(ast: &syn::DeriveInput) -> TokenStream {
     };
 
     let num_lifetimes = ast.generics.lifetimes().count();
-    if num_lifetimes > 1 { panic!("Enum can only have one lifetime argument"); }
+    if num_lifetimes > 1 {
+        panic!("Enum can only have one lifetime argument");
+    }
     let has_lifetime = num_lifetimes == 1;
 
     for variant in variants {
@@ -25,13 +27,16 @@ pub fn transcoder_decorator(ast: &syn::DeriveInput) -> TokenStream {
         }
     }
 
-    let atoms: Vec<TokenStream> = variants.iter().map(|variant| {
-        let atom_str = variant.ident.to_string().to_snake_case();
-        let atom_fn  = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
-        quote! {
-            atom #atom_fn = #atom_str;
-        }
-    }).collect();
+    let atoms: Vec<TokenStream> = variants
+        .iter()
+        .map(|variant| {
+            let atom_str = variant.ident.to_string().to_snake_case();
+            let atom_fn = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
+            quote! {
+                atom #atom_fn = #atom_str;
+            }
+        })
+        .collect();
 
     let atom_defs = quote! {
         ::rustler::rustler_atoms! {
@@ -41,46 +46,52 @@ pub fn transcoder_decorator(ast: &syn::DeriveInput) -> TokenStream {
 
     let variants: Vec<&Variant> = variants.iter().collect();
 
-    let decoder =
-        if ctx.decode() {
-            gen_decoder(&ast.ident, &variants, &atom_defs, has_lifetime)
-        } else {
-            quote! {}
-        };
+    let decoder = if ctx.decode() {
+        gen_decoder(&ast.ident, &variants, &atom_defs, has_lifetime)
+    } else {
+        quote! {}
+    };
 
-    let encoder =
-        if ctx.encode() {
-            gen_encoder(&ast.ident, &variants, &atom_defs, has_lifetime)
-        } else {
-            quote! {}
-        };
+    let encoder = if ctx.encode() {
+        gen_encoder(&ast.ident, &variants, &atom_defs, has_lifetime)
+    } else {
+        quote! {}
+    };
 
     let gen = quote! {
         #decoder
         #encoder
     };
 
-    gen.into()
+    gen
 }
 
-pub fn gen_decoder(enum_name: &Ident, variants: &[&Variant], atom_defs: &TokenStream, has_lifetime: bool) -> TokenStream {
+pub fn gen_decoder(
+    enum_name: &Ident,
+    variants: &[&Variant],
+    atom_defs: &TokenStream,
+    has_lifetime: bool,
+) -> TokenStream {
     let enum_type = if has_lifetime {
         quote! { #enum_name <'b> }
     } else {
         quote! { #enum_name }
     };
 
-    let variant_defs: Vec<TokenStream> = variants.iter().map(|variant| {
-        let variant_ident = &variant.ident;
-        let atom_str      = variant_ident.to_string().to_snake_case();
-        let atom_fn       = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
+    let variant_defs: Vec<TokenStream> = variants
+        .iter()
+        .map(|variant| {
+            let variant_ident = &variant.ident;
+            let atom_str = variant_ident.to_string().to_snake_case();
+            let atom_fn = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
 
-        quote! {
-            if value == #atom_fn() {
-                return Ok ( #enum_name :: #variant_ident );
+            quote! {
+                if value == #atom_fn() {
+                    return Ok ( #enum_name :: #variant_ident );
+                }
             }
-        }
-    }).collect();
+        })
+        .collect();
 
     let gen = quote! {
         impl<'a> ::rustler::Decoder<'a> for #enum_type {
@@ -96,25 +107,33 @@ pub fn gen_decoder(enum_name: &Ident, variants: &[&Variant], atom_defs: &TokenSt
         }
     };
 
-    gen.into()
+    gen
 }
 
-pub fn gen_encoder(enum_name: &Ident, variants: &[&Variant], atom_defs: &TokenStream, has_lifetime: bool) -> TokenStream {
+pub fn gen_encoder(
+    enum_name: &Ident,
+    variants: &[&Variant],
+    atom_defs: &TokenStream,
+    has_lifetime: bool,
+) -> TokenStream {
     let enum_type = if has_lifetime {
         quote! { #enum_name <'b> }
     } else {
         quote! { #enum_name }
     };
 
-    let variant_defs: Vec<TokenStream> = variants.iter().map(|variant| {
-        let variant_ident = &variant.ident;
-        let atom_str      = variant_ident.to_string().to_snake_case();
-        let atom_fn       = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
+    let variant_defs: Vec<TokenStream> = variants
+        .iter()
+        .map(|variant| {
+            let variant_ident = &variant.ident;
+            let atom_str = variant_ident.to_string().to_snake_case();
+            let atom_fn = Ident::new(&format!("atom_{}", atom_str), Span::call_site());
 
-        quote! {
-            #enum_name :: #variant_ident => #atom_fn().encode(env),
-        }
-    }).collect();
+            quote! {
+                #enum_name :: #variant_ident => #atom_fn().encode(env),
+            }
+        })
+        .collect();
 
     let gen = quote! {
         impl<'b> ::rustler::Encoder for #enum_type {
@@ -128,5 +147,5 @@ pub fn gen_encoder(enum_name: &Ident, variants: &[&Variant], atom_defs: &TokenSt
         }
     };
 
-    gen.into()
+    gen
 }
